// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_EWSCLI_PROTO_LOG_EWSCLI_PROTO_DEBUG_H
#define ECM_QLOGGINGCATEGORY_EWSCLI_PROTO_LOG_EWSCLI_PROTO_DEBUG_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(EWSCLI_PROTO_LOG)


#endif
