/****************************************************************************
** Meta object code from reading C++ file 'googleresource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdepim-runtime-26.08.0/resources/google-groupware/googleresource.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'googleresource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14GoogleResourceE_t {};
} // unnamed namespace

template <> constexpr inline auto GoogleResource::qt_create_metaobjectdata<qt_meta_tag_ZN14GoogleResourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GoogleResource",
        "reloadConfig",
        "",
        "retrieveCollections",
        "retrieveItems",
        "Akonadi::Collection",
        "collection",
        "Akonadi::Item::List",
        "items",
        "QSet<QByteArray>",
        "parts",
        "itemAdded",
        "Akonadi::Item",
        "item",
        "itemChanged",
        "partIdentifiers",
        "itemsRemoved",
        "itemsMoved",
        "collectionSource",
        "collectionDestination",
        "itemsLinked",
        "itemsUnlinked",
        "itemsTagsChanged",
        "QSet<Akonadi::Tag>",
        "addedTags",
        "removedTags",
        "collectionAdded",
        "parent",
        "collectionChanged",
        "collectionRemoved",
        "handleError",
        "KGAPI2::Job*",
        "job",
        "cancelTask",
        "slotAuthJobFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'reloadConfig'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'retrieveCollections'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'retrieveItems'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(4, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'retrieveItems'
        QtMocHelpers::SlotData<bool(const Akonadi::Item::List &, const QSet<QByteArray> &)>(4, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'itemAdded'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const Akonadi::Collection &)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'itemChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const QSet<QByteArray> &)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 9, 15 },
        }}),
        // Slot 'itemsRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'itemsMoved'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const Akonadi::Collection &, const Akonadi::Collection &)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 5, 18 }, { 0x80000000 | 5, 19 },
        }}),
        // Slot 'itemsLinked'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const Akonadi::Collection &)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'itemsUnlinked'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const Akonadi::Collection &)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'itemsTagsChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const QSet<Akonadi::Tag> &, const QSet<Akonadi::Tag> &)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 23, 24 }, { 0x80000000 | 23, 25 },
        }}),
        // Slot 'collectionAdded'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, const Akonadi::Collection &)>(26, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 27 },
        }}),
        // Slot 'collectionChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(28, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'collectionRemoved'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(29, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'handleError'
        QtMocHelpers::SlotData<bool(KGAPI2::Job *, bool)>(30, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 31, 32 }, { QMetaType::Bool, 33 },
        }}),
        // Slot 'handleError'
        QtMocHelpers::SlotData<bool(KGAPI2::Job *)>(30, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'slotAuthJobFinished'
        QtMocHelpers::SlotData<void(KGAPI2::Job *)>(34, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GoogleResource, qt_meta_tag_ZN14GoogleResourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GoogleResource::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::ResourceWidgetBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14GoogleResourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14GoogleResourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14GoogleResourceE_t>.metaTypes,
    nullptr
} };

void GoogleResource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GoogleResource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reloadConfig(); break;
        case 1: _t->retrieveCollections(); break;
        case 2: _t->retrieveItems((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 3: { bool _r = _t->retrieveItems((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->itemAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 5: _t->itemChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2]))); break;
        case 6: _t->itemsRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1]))); break;
        case 7: _t->itemsMoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[3]))); break;
        case 8: _t->itemsLinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 9: _t->itemsUnlinked((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 10: _t->itemsTagsChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<Akonadi::Tag>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSet<Akonadi::Tag>>>(_a[3]))); break;
        case 11: _t->collectionAdded((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[2]))); break;
        case 12: _t->collectionChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 13: _t->collectionRemoved((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 14: { bool _r = _t->handleError((*reinterpret_cast<std::add_pointer_t<KGAPI2::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->handleError((*reinterpret_cast<std::add_pointer_t<KGAPI2::Job*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->slotAuthJobFinished((*reinterpret_cast<std::add_pointer_t<KGAPI2::Job*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<Akonadi::Tag> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *GoogleResource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GoogleResource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14GoogleResourceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Akonadi::AgentBase::ObserverV3"))
        return static_cast< Akonadi::AgentBase::ObserverV3*>(this);
    if (!strcmp(_clname, "Akonadi::AgentBase::TagObserver"))
        return static_cast< Akonadi::AgentBase::TagObserver*>(this);
    if (!strcmp(_clname, "Akonadi::FreeBusyProviderBase"))
        return static_cast< Akonadi::FreeBusyProviderBase*>(this);
    if (!strcmp(_clname, "Akonadi::AccountBase"))
        return static_cast< Akonadi::AccountBase*>(this);
    return Akonadi::ResourceWidgetBase::qt_metacast(_clname);
}

int GoogleResource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::ResourceWidgetBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
