/****************************************************************************
** Meta object code from reading C++ file 'maildispatcheragent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdepim-runtime-26.08.0/agents/maildispatcher/maildispatcheragent.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'maildispatcheragent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19MailDispatcherAgentE_t {};
} // unnamed namespace

template <> constexpr inline auto MailDispatcherAgent::qt_create_metaobjectdata<qt_meta_tag_ZN19MailDispatcherAgentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailDispatcherAgent",
        "D-Bus Interface",
        "org.freedesktop.Akonadi.MailDispatcherAgent",
        "itemProcessed",
        "",
        "Akonadi::Item",
        "item",
        "result",
        "itemDispatchStarted",
        "sendPercent",
        "KJob*",
        "job",
        "percent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'itemProcessed'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'itemDispatchStarted'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'sendPercent'
        QtMocHelpers::SlotData<void(KJob *, unsigned long)>(9, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::ULong, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MailDispatcherAgent, qt_meta_tag_ZN19MailDispatcherAgentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MailDispatcherAgent::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::AgentWidgetBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MailDispatcherAgentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MailDispatcherAgentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19MailDispatcherAgentE_t>.metaTypes,
    nullptr
} };

void MailDispatcherAgent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MailDispatcherAgent *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemProcessed((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->itemDispatchStarted(); break;
        case 2: _t->sendPercent((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MailDispatcherAgent::*)(const Akonadi::Item & , bool )>(_a, &MailDispatcherAgent::itemProcessed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MailDispatcherAgent::*)()>(_a, &MailDispatcherAgent::itemDispatchStarted, 1))
            return;
    }
}

const QMetaObject *MailDispatcherAgent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailDispatcherAgent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MailDispatcherAgentE_t>.strings))
        return static_cast<void*>(this);
    return Akonadi::AgentWidgetBase::qt_metacast(_clname);
}

int MailDispatcherAgent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::AgentWidgetBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void MailDispatcherAgent::itemProcessed(const Akonadi::Item & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void MailDispatcherAgent::itemDispatchStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
